@@ -1,9 +1,9 @@
 #
-# $Id: String.pm,v 0.1 2004/01/06 03:33:26 sts Exp $
+# $Id: String.pm,v 0.2 2004/01/06 03:33:26 sts Exp $
 
 package Convert::ASCII::String;
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 use strict 'vars';
 use warnings;
@@ -25,7 +25,7 @@ sub SEP_MISMATCH { -2 }
 
 =head1 NAME
 
-Convert::ASCII::String - Convert character strings to ASCII and vice versa.
+Convert::ASCII::String - convert character strings to ASCII and vice versa.
 
 =head1 SYNOPSIS
 
@@ -166,31 +166,13 @@ The separator may alternatively be set by
 
 Function delivery becomes then superfluous.
 
-=head1 EXPORTABLE
+=head2 EXPORT
 
-=head2 FUNCTIONS
-
-=over 4
-
-=item *
-
-C<string2ascii()>
-
-=item *
-
-C<ascii2string()>
-
-=back
+C<string2ascii(), ascii2string()> upon request.
 
 =head2 TAGS
 
-=over 4
-
-=item *
-
-C<:all  - *()>
-
-=back
+C<:all - *()>
 
 =head1 SEE ALSO
 
